@@ -74,7 +74,7 @@ def get_performance_results(
     if mode != '':
         mode += '_'
 
-    if verbose:
+    if verbose:   # pragma: no cover
         print(
             'There are '
             + str(np.count_nonzero(np.array(pred_values_arr)))
@@ -94,7 +94,7 @@ def get_performance_results(
     if isinstance(targets_arr, list):
         targets_arr = np.array(targets_arr)
 
-    if verbose:
+    if verbose:   # pragma: no cover
         print('train_true_value: ' + str(train_true_value))
         print('True_values length: ' + str(len(true_values_arr)))
         print('Predicted_values length: ' + str(len(pred_values_arr)))
@@ -105,7 +105,7 @@ def get_performance_results(
 
     values_per_metric = {m: [] for m in metrics}
 
-    if verbose: print('========== ' + str(mode) + ' ==========')
+    if verbose: print('========== ' + str(mode) + ' ==========')   # pragma: no cover
 
     # for Setting A, the only averating option that makes sense is the micro version.
     if validation_setting == 'A':
@@ -128,7 +128,7 @@ def get_performance_results(
             # iterate the metric_name, metric_value pairs
             for metric_name, metric_val in results.items():
                 final_result.update({mode + metric_name + '_micro': metric_val})
-                if verbose:
+                if verbose:   # pragma: no cover
                     print(metric_name + '_micro: ' + str(metric_val))
 
         else:
@@ -156,7 +156,7 @@ def get_performance_results(
                     .flatten()
                 )
 
-            if verbose:
+            if verbose:   # pragma: no cover
                 print('Unscaled True_values: ' + str(true_values_arr[:10]))
                 print('Unscaled Predicted_values: ' + str(pred_values_arr[:10]))
 
@@ -167,7 +167,7 @@ def get_performance_results(
             # iterate the metric_name, metric_value pairs
             for metric_name, metric_val in results.items():
                 final_result.update({mode + metric_name + '_micro': metric_val})
-                if verbose:
+                if verbose:   # pragma: no cover
                     print(metric_name + '_micro: ' + str(metric_val))
 
         if 'macro' in averaging:
@@ -178,7 +178,7 @@ def get_performance_results(
 
             # iterate over the targets
             for target_i, idxs in index_arr_per_target.items():
-                if (len(np.unique(true_values_arr[idxs])) > 1) or (len(np.unique(pred_values_arr[idxs])) > 1):
+                if problem_mode=='regression' or (len(np.unique(true_values_arr[idxs])) > 1) or (len(np.unique(pred_values_arr[idxs])) > 1):
 
                     results = base_evaluator(
                         true_values_arr[idxs],
@@ -203,7 +203,7 @@ def get_performance_results(
                                 + str(target_i): metric_val
                             }
                         )
-                        if per_target_verbose:
+                        if per_target_verbose:   # pragma: no cover
                             print(
                                 metric_name
                                 + '_target_'
@@ -212,7 +212,7 @@ def get_performance_results(
                                 + str(metric_val)
                             )
                 else:
-                    if verbose:
+                    if verbose:   # pragma: no cover
                         print(
                             'Warning: Target'
                             + str(target_i)
@@ -226,7 +226,7 @@ def get_performance_results(
             for metric_name in values_per_metric.keys():
                 avg_val = np.mean(values_per_metric[metric_name])
                 final_result.update({mode + metric_name + '_macro': avg_val})
-                if verbose:
+                if verbose:   # pragma: no cover
                     print(metric_name + '_macro: ' + str(avg_val))
 
         if 'instance' in averaging:
@@ -237,7 +237,7 @@ def get_performance_results(
 
             # iterate over the instances
             for instance_i, idxs in index_arr_per_instance.items():
-                if (len(np.unique(true_values_arr[idxs])) > 1) and (len(np.unique(pred_values_arr[idxs])) > 1):
+                if problem_mode=='regression' or (len(np.unique(true_values_arr[idxs])) > 1) and (len(np.unique(pred_values_arr[idxs])) > 1):
 
                     results = base_evaluator(
                         true_values_arr[idxs],
@@ -259,10 +259,10 @@ def get_performance_results(
                                 mode
                                 + metric_name
                                 + '_instance_'
-                                + str(target_i): metric_val
+                                + str(instance_i): metric_val
                             }
                         )
-                        if per_instance_verbose:
+                        if per_instance_verbose:   # pragma: no cover
                             print(
                                 metric_name
                                 + '_instance_'
@@ -272,7 +272,7 @@ def get_performance_results(
                             )
 
                 else:
-                    if verbose:
+                    if verbose:   # pragma: no cover
                         print(
                             'Warning: Instance'
                             + str(instance_i)
@@ -286,10 +286,10 @@ def get_performance_results(
             for metric_name in metrics:
                 avg_val = np.mean(values_per_metric[metric_name])
                 final_result.update({mode + metric_name + '_instance': avg_val})
-                if verbose:
+                if verbose:   # pragma: no cover
                     print(metric_name + '_instance: ' + str(avg_val))
 
-    if verbose:
+    if verbose:   # pragma: no cover
         print('==================================')
         print('')
 
@@ -297,7 +297,7 @@ def get_performance_results(
 
 
 # with micro-averaging you loose the notion of multiple-targets. You just simplify the problem and assume you are working with just one target. The train_true_value variable is only used for the calculation of the relative root mean squared error RRMSE.
-def base_evaluator(
+def base_evaluator(   # pragma: no cover
     true_values_arr, pred_values_arr, problem_mode, metrics, idx, train_true_value=None, verbose=False
 ):
     '''The function that actually calculates the different metrics
@@ -325,7 +325,7 @@ def base_evaluator(
             results['MAE'] = np.mean(np.abs(true_values_arr - pred_values_arr))
         if 'R2' in metrics:
             results['R2'] = r2_score(true_values_arr, pred_values_arr)
-        if 'RRMSE' in metrics:
+        if 'RRMSE' in metrics:   # pragma: no cover
             if train_true_value is None:
                 results['RRMSE'] = np.nan
                 # raise Exception(
@@ -375,7 +375,7 @@ def base_evaluator(
                 )
                 results['aupr'] = auc(recall, precision)
         else:
-            if verbose:
+            if verbose:   # pragma: no cover
                 print(
                     'Warning: instance'
                     + str(idx)
@@ -424,7 +424,7 @@ def get_epilepsy_specific_metrics(
         'positive_predictive_value',
         'f1_score_epilepsy_version',
     ],
-):
+):   # pragma: no cover
     '''Function that calculates specific metrics used in Epilepsy prediction tasks
 
     Args:
