@@ -9,12 +9,12 @@ def get_optimization_direction(metric_name: str) -> str:
     Returns:
         string: max if the goal is go maximize or min if the goal is to mimize  
     '''
-    metrics_to_max = ['sensitivity', 'f1_score', 'recall', 'positive_predictive_value']
+    metrics_to_max = ['sensitivity', 'f1_score', 'recall', 'positive_predictive_value', 'R2', 'accuracy', 'precision', 'auroc', 'aupr']
     if True in [n in metric_name for n in metrics_to_max]:
         return 'max'
     return 'min'
 
-class BaseExperimentInfo:
+class BaseExperimentInfo:    # pragma: no cover
     """A class used to keep track of all relevant info of a given experiment. This is mainly used by the HPO methods.
     """    
     def __init__(self, config, budget):
@@ -64,7 +64,7 @@ class BaseExperimentInfo:
             + '\n'
         )
 
-def get_default_dropout_rate():
+def get_default_dropout_rate():    # pragma: no cover
     ''' To return the default dropout rate
 
     Returns:
@@ -72,7 +72,7 @@ def get_default_dropout_rate():
     '''    
     return 0
 
-def get_default_batch_norm():
+def get_default_batch_norm():    # pragma: no cover
     ''' To return the default batch_norm value
 
     Returns:
@@ -81,7 +81,7 @@ def get_default_batch_norm():
     return False
 
 # dafault transofmations applied for resnet inputs 
-def get_default_train_transform():
+def get_default_train_transform():    # pragma: no cover
     ''' To return the default transformation pipeline for a resnet during training
 
     Returns:
@@ -99,7 +99,7 @@ def get_default_train_transform():
                            transforms.Normalize(mean = pretrained_means, 
                                                 std = pretrained_stds)
                        ])
-def get_default_inference_transform():
+def get_default_inference_transform():    # pragma: no cover
     ''' To return the default transformation pipeline for a resnet during inference
 
     Returns:
@@ -133,6 +133,7 @@ def generate_config(
     metrics = ['hamming_loss', 'auroc', 'f1_score', 'aupr', 'accuracy', 'recall', 'precision'],
     metrics_average = ['macro', 'micro'],
     patience = 10,
+    delta = 0,
 
     evaluate_train = False,
     evaluate_val = False,
@@ -166,7 +167,7 @@ def generate_config(
 
     comb_mlp_nodes_reducing_factor = 2,
     comb_mlp_nodes_per_layer = [10, 10, 10],
-    comb_mlp_branch_layers = None,
+    comb_mlp_layers = None,
 
     embedding_size = 100,
     eval_every_n_epochs = 10,
@@ -178,6 +179,7 @@ def generate_config(
 
     instance_branch_params = {},
     target_branch_params = {},
+    hpo_results_path = './',
 
 ):
     ''' Creates a dictionary that is used to configure the neural network. Contains some base logic that checks if some of the parameters make sense. It has to be updated each time a new feature is added.
@@ -200,6 +202,7 @@ def generate_config(
         metrics (list, optional): The performance metrics that will be calculated. For classification tasks the available metrics are ['hamming_loss', 'auroc', 'f1_score', 'aupr', 'accuracy', 'recall', 'precision'] while for regression tasks the available metrics are ['RMSE', 'MSE', 'MAE', 'R2', 'RRMSE']. Defaults to ['hamming_loss', 'auroc', 'f1_score', 'aupr', 'accuracy', 'recall', 'precision'].
         metrics_average (list, optional): The averaging strategy that will be used to calculate the metric. The available options are ['macro', 'micro', 'instance']. Defaults to ['macro', 'micro'].
         patience (int, optional): The number of epochs that the network is allowed to continue training for while observing worse overall performance. Defaults to 10.
+        delta (float, optional): The delta used during early stopping
         evaluate_train (bool, optional): Whether or not to calculate performance metrics over the training set. Defaults to False.
         evaluate_val (bool, optional): 	Whether or not to calculate performance metrics over the validation set. Defaults to False.
         verbose (bool, optional): Whether or not to print useful info about the training process in the terminal. Defaults to False.
@@ -239,8 +242,8 @@ def generate_config(
         target_branch_conv_architecture_dense_layers (int, optional): The number of dense layers that are used at the end of the convolutional architecture of the target branch. Defaults to 1.
         target_branch_conv_architecture_last_layer_trained (str, optional): When using pre-trained architectures, the user can define that last layer that will be frozen during training. Defaults to 'last'.
         comb_mlp_nodes_reducing_factor (int, optional): The factor that will be used to create a smooth bottleneck in the combination MLP. (Only used if general_architecture_version in "mlp"). Not currently implemented. Defaults to 2.
-        comb_mlp_nodes_per_layer (list, optional): The number of nodes in the combination branch. If list, each element defines the number of nodes in the corresponding layer. If int, the same number of nodes is used 'comb_mlp_branch_layers' times. (Only used if general_architecture_version in "mlp" or "kronecker")). Defaults to [10, 10, 10].
-        comb_mlp_branch_layers (int, optional): The number of layers in the combination branch. (Only used if general_architecture_version in "mlp"). Defaults to None.
+        comb_mlp_nodes_per_layer (list, optional): The number of nodes in the combination branch. If list, each element defines the number of nodes in the corresponding layer. If int, the same number of nodes is used 'comb_mlp_layers' times. (Only used if general_architecture_version in "mlp" or "kronecker")). Defaults to [10, 10, 10].
+        comb_mlp_layers (int, optional): The number of layers in the combination branch. (Only used if general_architecture_version in "mlp"). Defaults to None.
         embedding_size (int, optional): The size of the embeddings outputted by the two branches. (Only used if general_architecture_version in "dot_product"). Defaults to 100.
         eval_every_n_epochs (int, optional): The interval that indicates when the performance metrics are computed. Defaults to 10.
         load_pretrained_model (bool, optional): Whether or not a pretrained model will be loaded. Defaults to False.
@@ -249,19 +252,13 @@ def generate_config(
         additional_info (dict, optional): A dictionary that holds all other relevant info. Can be used as log adittional info for an experiment in wandb. Defaults to {}.
         eval_instance_verbose (str, optional): Printing of instance-wise warnings when evaluating performance metrics.
         eval_target_verbose (str, optional): Printing of target-wise warnings when evaluating performance metrics.
-
+        hpo_results_path (str, optional): The directory the HPO results will be stored.
     Returns:
         dict: A dictionary with the config that will be used by the model to adjust the architecture and all other training-related information
     '''
-    if metrics is not None and len(metrics) != 0:
-        if metric_to_optimize_early_stopping not in [m+'_'+m_a for m in metrics for m_a in metrics_average]+['loss']:
-            raise AttributeError('The metric requested to track during early stopping ('+metric_to_optimize_early_stopping+') is should be also defined in the metrics field of the configuration object '+str([m+'_'+m_a for m in metrics+['loss'] for m_a in metrics_average]))
-    else:
-        metrics = []
-        metrics_average = []
-        if metric_to_optimize_early_stopping != 'loss':
-            raise AttributeError('Only loss can be used for early stopping. To use '+metric_to_optimize_early_stopping+' it should be added in the metrics config parameter')
 
+    if metric_to_optimize_early_stopping not in [m+'_'+m_a for m in metrics for m_a in metrics_average]+['loss']:
+        raise AttributeError('The metric requested to track during early stopping ('+metric_to_optimize_early_stopping+') is should be also defined in the metrics field of the configuration object '+str([m+'_'+m_a for m in metrics+['loss'] for m_a in metrics_average]))
 
     base_config = {
         'validation_setting': validation_setting,
@@ -280,6 +277,7 @@ def generate_config(
         'num_epochs': num_epochs,
         'use_early_stopping': use_early_stopping,
         'patience': patience,
+        'delta': delta,
         'evaluate_train': evaluate_train,
         'evaluate_val': evaluate_val,
         'verbose': verbose,
@@ -309,44 +307,44 @@ def generate_config(
         'target_train_transforms': target_train_transforms,
         'target_inference_transforms': target_inference_transforms,
         'running_hpo': running_hpo,
+        'hpo_results_path': hpo_results_path,
     }
 
     # various sanity checks for the metrics and averaging options that are provided by the user
     classification_metrics = ['hamming_loss', 'auroc', 'f1_score', 'aupr', 'accuracy', 'recall', 'precision']
     regression_metrics = ['RMSE', 'MSE', 'MAE', 'R2', 'RRMSE']
-    if metrics:
-        if problem_mode == 'classification':
-            metrics = [m.lower() for m in metrics]
-            unknown_metrics = set(metrics).difference(set(classification_metrics))
-            if unknown_metrics != set():
-                raise Exception('Detected unknown metrics for the current classification task: '+str(unknown_metrics))
-        else:
-            metrics = [m.upper() for m in metrics]
-            unknown_metrics = set(metrics).difference(set(regression_metrics))
-            if unknown_metrics != set():
-                raise Exception('Detected unknown metrics for the current regression task: '+str(unknown_metrics))
-        
+    if problem_mode == 'classification':
+        metrics = [m.lower() for m in metrics]
+        unknown_metrics = set(metrics).difference(set(classification_metrics))
+        if unknown_metrics != set():
+            raise Exception('Detected unknown metrics for the current classification task: '+str(unknown_metrics))
+    else:
+        metrics = [m.upper() for m in metrics]
+        unknown_metrics = set(metrics).difference(set(regression_metrics))
+        if unknown_metrics != set():
+            raise Exception('Detected unknown metrics for the current regression task: '+str(unknown_metrics))
+    
 
-        metric_averaging_schemes = ['macro', 'micro', 'instance']
-        metrics_average = [m.lower() for m in metrics_average]
-        unknown_metric_averaging_schemes = set(metrics_average).difference(set(metric_averaging_schemes))
-        if unknown_metric_averaging_schemes != set():
-            raise Exception('Detected unknown metric averaging scheme for the current '+problem_mode+' task: '+str(unknown_metric_averaging_schemes))    
-            
-        if validation_setting == 'A':
-            if 'instance' in metrics or 'macro' in metrics:
-                print('The macro and instance-wise averaging schemes are not recommended while on validation setting A. The experiments will calculate the micro averaged version of the selected metrics')
-                metrics_average = ['micro']
-        elif validation_setting in ['B', 'C']:
-            if 'macro' not in metrics_average:
-                print('Macro-averaging is the adviced averaging option for validation setting '+validation_setting+'. The macro option will be included in the results')
-                metrics_average.append('macro')
-        elif validation_setting == 'D':
-            if 'micro' not in metrics_average:
-                print('Micro-averaging is the adviced averaging option for validation setting '+validation_setting+'. The micro option will be included in the results')
-                metrics_average.append('micro')
-        else:
-            raise Exception('Validation setting '+validation_setting+' is not recognized.')
+    metric_averaging_schemes = ['macro', 'micro', 'instance']
+    metrics_average = [m.lower() for m in metrics_average]
+    unknown_metric_averaging_schemes = set(metrics_average).difference(set(metric_averaging_schemes))
+    if unknown_metric_averaging_schemes != set():
+        raise Exception('Detected unknown metric averaging scheme for the current '+problem_mode+' task: '+str(unknown_metric_averaging_schemes))    
+        
+    if validation_setting == 'A':
+        if 'micro' not in metrics_average:
+            print('The macro and instance-wise averaging schemes are not recommended while on validation setting A. The experiments will calculate the micro averaged version of the selected metrics')
+            metrics_average.append('micro')
+    elif validation_setting in ['B', 'C']:
+        if 'macro' not in metrics_average:
+            print('Macro-averaging is the adviced averaging option for validation setting '+validation_setting+'. The macro option will be included in the results')
+            metrics_average.append('macro')
+    elif validation_setting == 'D':
+        if 'micro' not in metrics_average:
+            print('Micro-averaging is the adviced averaging option for validation setting '+validation_setting+'. The micro option will be included in the results')
+            metrics_average.append('micro')
+    else:
+        raise Exception('Validation setting '+validation_setting+' is not recognized.')
         
     base_config['metrics'] = metrics
     base_config['metrics_average'] = metrics_average
@@ -363,7 +361,7 @@ def generate_config(
         base_config.update(
             {
                 'comb_mlp_nodes_per_layer': comb_mlp_nodes_per_layer,
-                'comb_mlp_branch_layers': comb_mlp_branch_layers,
+                'comb_mlp_layers': comb_mlp_layers,
                 'comb_mlp_nodes_reducing_factor': comb_mlp_nodes_reducing_factor,
             }
         )
